@@ -5,9 +5,12 @@ import smtplib
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from os.path import expanduser, join
-from typing import Any, List, Optional
+from typing import Any, List, Optional, Union
 
-from email_validator import validate_email
+try:
+    from email_validator import validate_email
+except ImportError:
+    validate_email = None
 
 from hdx.utilities.loader import load_json, load_yaml
 
@@ -37,7 +40,9 @@ class Email:
         email_config_yaml (str): Path to YAML HDX configuration. Defaults to ~/hdx_email_configuration.yml.
     """
 
-    default_email_config_yaml = join(expanduser("~"), "hdx_email_configuration.yml")
+    default_email_config_yaml = join(
+        expanduser("~"), "hdx_email_configuration.yml"
+    )
 
     def __init__(self, **kwargs: Any) -> None:
         email_config_found = False
@@ -53,7 +58,9 @@ class Email:
                     "More than one email configuration file given!"
                 )
             email_config_found = True
-            logger.info(f"Loading email configuration from: {email_config_json}")
+            logger.info(
+                f"Loading email configuration from: {email_config_json}"
+            )
             email_config_dict = load_json(email_config_json)
 
         email_config_yaml = kwargs.get("email_config_yaml", None)
@@ -68,7 +75,9 @@ class Email:
                     "No email configuration parameter. Using default email configuration path."
                 )
                 email_config_yaml = Email.default_email_config_yaml
-            logger.info(f"Loading email configuration from: {email_config_yaml}")
+            logger.info(
+                f"Loading email configuration from: {email_config_yaml}"
+            )
             email_config_dict = load_yaml(email_config_yaml)
 
         self.connection_type = email_config_dict.get("connection_type", "smtp")
@@ -148,50 +157,57 @@ class Email:
         self.server.quit()
 
     @staticmethod
-    def get_normalised_emails(recipients: List[str]) -> List[str]:
+    def get_normalised_emails(recipients: Union[str, List[str]]) -> List[str]:
         """
         Get list of normalised emails
 
         Args:
-            recipients (List[str]): Email recipient
+            recipients (Union[str, List[str]]): Email recipient(s)
 
         Returns:
             List[str]: Normalised emails
 
         """
+        if isinstance(recipients, str):
+            recipients = [recipients]
+        if validate_email is None:
+            return recipients
         normalised_recipients = list()
         for recipient in recipients:
             v = validate_email(
                 recipient, check_deliverability=True
             )  # validate and get info
-            normalised_recipients.append(v["email"])  # replace with normalized form
+            normalised_recipients.append(
+                v["email"]
+            )  # replace with normalized form
         return normalised_recipients
 
     def send(
         self,
-        recipients: List[str],
+        to: Union[str, List[str]],
         subject: str,
         text_body: str,
         html_body: Optional[str] = None,
         sender: Optional[str] = None,
-        cc: Optional[List[str]] = None,
-        bcc: Optional[List[str]] = None,
+        cc: Union[str, List[str], None] = None,
+        bcc: Union[str, List[str], None] = None,
         **kwargs: Any,
     ) -> None:
         """
-        Send email
+        Send email. to, cc and bcc take either a string email address or a list of
+        string email addresses. cc and bcc default to None.
 
         Args:
-            recipients (List[str]): Email recipient
+            to (Union[str, List[str]]): Email recipient(s)
             subject (str): Email subject
             text_body (str): Plain text email body
             html_body (Optional[str]): HTML email body
             sender (Optional[str]): Email sender. Defaults to global sender.
-            cc (Optional[List[str]]): Email cc. Defaults to None.
-            bcc (Optional[List[str]]): Email cc. Defaults to None.
+            cc (Union[str, List[str], None]): Email cc. Defaults to None.
+            bcc (Union[str, List[str], None]): Email bcc. Defaults to None.
             **kwargs: See below
-            mail_options (list): Mail options (see smtplib documentation)
-            rcpt_options (list): Recipient options (see smtplib documentation)
+            mail_options (List): Mail options (see smtplib documentation)
+            rcpt_options (List): Recipient options (see smtplib documentation)
 
         Returns:
             None
@@ -199,7 +215,9 @@ class Email:
         """
         if sender is None:
             sender = self.sender
-        v = validate_email(sender, check_deliverability=False)  # validate and get info
+        v = validate_email(
+            sender, check_deliverability=False
+        )  # validate and get info
         sender = v["email"]  # replace with normalized form
 
         if html_body is not None:
@@ -213,19 +231,19 @@ class Email:
         msg["Subject"] = subject
         msg["From"] = sender
 
-        normalised_recipients = self.get_normalised_emails(recipients)
-        msg["To"] = ", ".join(normalised_recipients)
+        normalised_to = self.get_normalised_emails(to)
+        msg["To"] = ", ".join(normalised_to)
 
         if cc is not None:
             normalised_cc = self.get_normalised_emails(cc)
             msg["Cc"] = ", ".join(normalised_cc)
-            normalised_recipients.extend(normalised_cc)
+            normalised_to.extend(normalised_cc)
 
         if bcc is not None:
             normalised_bcc = self.get_normalised_emails(bcc)
-            normalised_recipients.extend(normalised_bcc)
+            normalised_to.extend(normalised_bcc)
 
         # Perform operations via server
         self.connect()
-        self.server.sendmail(sender, normalised_recipients, msg.as_string(), **kwargs)
+        self.server.sendmail(sender, normalised_to, msg.as_string(), **kwargs)
         self.close()
