@@ -11,6 +11,8 @@ from tempfile import gettempdir
 from typing import Any, Dict, Iterable, List, Optional, Tuple
 from urllib.parse import urlsplit
 
+from slugify import slugify
+
 from hdx.utilities.loader import load_text
 from hdx.utilities.saver import save_text
 from hdx.utilities.uuid import get_uuid
@@ -404,28 +406,41 @@ def multiple_progress_storing_tempdir(
                     remove(progress_file)
 
 
-def get_filename_from_url(url: str) -> str:
+def get_filename_from_url(url: str, second_last: bool = False) -> str:
     """Get filename including extension from url
 
     Args:
         url (str): URL
+        second_last (bool): Get second last segment of url as well. Defaults to False.
 
     Returns:
         str: filename
 
     """
-    urlpath = urlsplit(url).path
-    return basename(urlpath)
+    split_url = urlsplit(url)
+    urlpath = split_url.path
+    if not urlpath or urlpath == "/":
+        last_part = slugify(split_url.query)
+    else:
+        last_part = basename(urlpath)
+    if second_last:
+        second_last_part = basename(dirname(urlpath))
+        if second_last_part:
+            return f"{second_last_part}_{last_part}"
+    return last_part
 
 
-def get_filename_extension_from_url(url: str) -> Tuple[str, str]:
+def get_filename_extension_from_url(
+    url: str, second_last: bool = False
+) -> Tuple[str, str]:
     """Get separately filename and extension from url
 
     Args:
         url (str): URL to download
+        second_last (bool): Get second last segment of url as well. Defaults to False.
 
     Returns:
         Tuple[str,str]: Tuple of (filename, extension)
 
     """
-    return splitext(get_filename_from_url(url))
+    return splitext(get_filename_from_url(url, second_last))
